#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 17-7-8
# @Author  : JCai
# @desc    :


from django.db import models
from django.utils import timezone


class EBayListing(models.Model):
    ItemID = models.CharField(max_length=20, null=True, unique=True, default='')  # 产品id
    Country = models.CharField(max_length=20, null=True, default='')
    Site = models.CharField(max_length=20, null=True, default='')
    Location = models.CharField(max_length=100, default='')
    currencyID = models.CharField(max_length=20, default='')
    ListingDuration = models.CharField(max_length=10, null=True, default='')
    ebay_account = models.IntegerField(db_column='ebay_account_id', null=True)  # 商店id
    Title = models.CharField(max_length=300, null=True)  # 产品标题
    image = models.CharField(max_length=300, null=True)  # 图片链接
    seller_sku = models.CharField(max_length=30, null=True)  # sku编码
    listing_price = models.FloatField(default=0.0, null=True)  # 产品价格
    start_price = models.FloatField(default=0.0, null=True)  # 产品价格
    reserve_price = models.FloatField(default=0.0, null=True)  # 产品价格
    buy_it_now_price = models.FloatField(default=0.0, null=True)  # 产品价格
    quantity = models.IntegerField(default=0, null=True)  # 库存
    open_date = models.DateTimeField(null=True)  # 上架时间
    QuantitySold = models.IntegerField(default=0, null=True)  # 销售量
    end_date = models.DateTimeField(null=True)  # end时间
    ListingType = models.CharField(max_length=20, default='')  ##ListingType
    WatchCount = models.IntegerField(default=0)  ##WatchCount
    ListingStatus = models.CharField(default='', max_length=15)

    no_single_day = models.IntegerField(default=0, help_text='未出单天数')
    ShippingServiceCost = models.FloatField(default=0.0, null=True)  # 第一运输运费
    variation = models.IntegerField(default=0, null=True)

    create_date = models.DateTimeField(default=timezone.now, help_text='记录创建时间')
    write_date = models.DateTimeField(default=timezone.now, help_text='记录更新时间')
    source = models.IntegerField(default=0,null=True,help_text="0其他平台上架，1pro上架，2铺货上架")

    class Meta:
        app_label = 'starpro'
        db_table = 'ebay_listing_info_base'


class EBayListingVariations(models.Model):
    ItemID = models.CharField(max_length=20, null=True, default='')  # 产品id
    seller_sku = models.CharField(default='', null=True, max_length=30)
    CurrentPrice = models.FloatField(default=0)
    Quantity = models.IntegerField(default=0, null=True)  # 库存
    QuantitySold = models.IntegerField(default=0, null=True)  # 销售量
    VariationSpecifics = models.CharField(default='', max_length=200)

    no_single_day = models.IntegerField(default=0, help_text='未出单天数')
    create_date = models.DateTimeField(default=timezone.now, help_text='记录创建时间')
    write_date = models.DateTimeField(default=timezone.now, help_text='记录更新时间')

    class Meta:
        app_label = 'starpro'
        db_table = 'ebay_listing_info_variations'


class EBayListingInfoMore(models.Model):
    ItemID = models.CharField(max_length=20, blank=True, null=True)
    description = models.TextField(blank=True, null=True)
    description_simple = models.TextField(blank=True, null=True)
    description_template_id = models.IntegerField(blank=True, null=True)
    description_title = models.CharField(max_length=300, blank=True, null=True)
    description_image = models.TextField(blank=True, null=True)
    description_content = models.TextField(blank=True, null=True)
    image_list = models.TextField(blank=True, null=True)
    dispatch_time_max = models.IntegerField(blank=True, null=True)
    shipping_domestic = models.TextField(blank=True, null=True)
    shipping_international = models.TextField(blank=True, null=True)
    exclude_ship_to_location = models.TextField(blank=True, null=True)
    return_policy = models.TextField(blank=True, null=True)
    buyer_requirement = models.TextField(blank=True, null=True)
    category_specifics = models.TextField(blank=True, null=True)
    category_specifics_original = models.TextField(blank=True, null=True)
    category_specifics_new = models.TextField(blank=True, null=True)
    variations = models.TextField(blank=True, null=True)
    variation_keys = models.TextField(blank=True, null=True)
    image = models.TextField(blank=True, null=True)
    payment_methods = models.TextField(blank=True, null=True)
    paypal_email_address = models.CharField(max_length=300, blank=True, null=True)
    payment_instruction = models.TextField(blank=True, null=True)
    post_code = models.CharField(max_length=100, blank=True, null=True)
    primary_category_id = models.CharField(max_length=20, blank=True, null=True)
    secondary_category_id = models.CharField(max_length=20, blank=True, null=True)
    store_category_id = models.CharField(max_length=20, blank=True, null=True)
    store_category_2id = models.CharField(max_length=20, blank=True, null=True)
    # variation_specific_name = models.CharField(max_length=20, blank=True, null=True)
    primary_category_name = models.CharField(max_length=300, blank=True, null=True)
    secondary_category_name = models.CharField(max_length=300, blank=True, null=True)
    # condition_id = models.IntegerField(blank=True, null=True)
    # listing_details = models.CharField(max_length=100, blank=True, null=True)
    sub_title = models.CharField(max_length=300, blank=True, null=True)
    condition_id = models.CharField(max_length=30, blank=True, null=True)


    class Meta:
        managed = False
        db_table = 'ebay_listing_info_more'
